Task: Dialogue_QE
==================
Description: Human-bot dialogues labelled for quality at the level of dialogues. Can be used to train dialogue-level metric for dialogue systems. Link to dataset: http://convai.io/data/

Tags: #Dialogue_QE, #All

